==> eiffelstudio-18.07.10.1981.tar: F_code/C2/di91.c <==
/*
 * Code for class DIRECTORY_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "di91.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DIRECTORY_ITERATOR}.process_directory */
void F108_2667 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	struct eif_ex_63 sloc4;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) sloc4.data;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTCFDT;
	RTCDT;
	RTLD;
	
	memset (&sloc4.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc4.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc4.overhead, eif_new_type(68, 0x00).id);
	RTLI(12);
	RTLR(0,loc3);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,loc6);
	RTLR(4,Current);
	RTLR(5,loc5);
	RTLR(6,loc7);
	RTLR(7,loc2);
	RTLR(8,loc1);
	RTLR(9,loc4);
	RTLR(10,loc8);
	RTLR(11,tr2);
	RTLIU(12);
	
	RTEAA("process_directory", 107, Current, 8, 1, 2857);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1072, 0x00).id, 1072, _OBJSIZ_3_0_0_1_0_2_0_0_);
	F1073_9109(RTCW(tr1), arg1);
	loc3 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F1073_9133(RTCW(loc3));
	if (tb2) {
		tr1 = F1073_9123(RTCW(loc3));
		loc6 = tr1;
		tb1 = EIF_TEST(loc6);
	}
	if (tb1) {
		RTHOOK(3);
		{
			static EIF_TYPE_INDEX typarr0[] = {990,1321,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNS(typres0.id, 990, _OBJSIZ_1_1_0_1_0_0_0_0_);
		}
		ti4_1 = F991_8643(loc6);
		F991_8623(RTCW(tr1), ti4_1);
		loc5 = (EIF_REFERENCE) tr1;
		RTHOOK(4);
		loc7 = F991_8636(loc6);
		for (;;) {
			tb1 = F812_8054(loc7);
			if (tb1) break;
			RTHOOK(5);
			loc2 = F812_8045(loc7);
			RTHOOK(6);
			if ((EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R2664[dtype-107])(Current, loc2)) {
				RTHOOK(7);
				if ((EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R2665[dtype-107])(Current, loc2)) {
					RTHOOK(8);
					loc1 = F1073_9113(RTCW(loc3));
					loc1 = F1322_12785(RTCW(loc1), loc2);
					RTHOOK(9);
					tb2 = F69_2065(RTCW(loc4), loc1);
					if (tb2) {
						RTHOOK(10);
						F991_8662(RTCW(loc5), loc2);
					}
				}
				RTHOOK(11);
				if ((EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R2666[dtype-107])(Current, loc2)) {
					RTHOOK(12);
					loc1 = F1073_9113(RTCW(loc3));
					loc1 = F1322_12785(RTCW(loc1), loc2);
					RTHOOK(13);
					tb2 = F69_2076(RTCW(loc4), loc1);
					if (tb2) {
						RTHOOK(14);
						(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2663[dtype-107])(Current, loc1);
					}
				}
			}
			RTHOOK(15);
			F812_8060(loc7);
		}
		RTHOOK(16);
		loc8 = F991_8636(RTCW(loc5));
		for (;;) {
			tb2 = F812_8054(loc8);
			if (tb2) break;
			RTHOOK(17);
			tr1 = F1073_9113(RTCW(loc3));
			tr2 = F812_8045(loc8);
			tr1 = F1322_12785(RTCW(tr1), tr2);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2662[dtype-107])(Current, tr1);
			RTHOOK(18);
			F812_8060(loc8);
		}
	}
	RTHOOK(19);
	RTLE;
	RTEE;
}

/* {DIRECTORY_ITERATOR}.process_file */
void F108_2668 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_file", 107, Current, 0, 1, 2858);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {DIRECTORY_ITERATOR}.path_excluded */
EIF_BOOLEAN F108_2669 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("path_excluded", 107, Current, 0, 1, 2859);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	tb1 = F1322_12762(RTCW(arg1));
	if (!tb1) {
		tb1 = F1322_12763(RTCW(arg1));
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {DIRECTORY_ITERATOR}.directory_excluded */
EIF_BOOLEAN F108_2670 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("directory_excluded", 107, Current, 0, 1, 2860);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {DIRECTORY_ITERATOR}.file_excluded */
EIF_BOOLEAN F108_2671 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("file_excluded", 107, Current, 0, 1, 2861);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

void EIF_Minit91 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/di91.c <==
/*
 * Code for class DIRECTORY_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "di91.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DIRECTORY_ITERATOR}.process_directory */
void F108_2667 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	struct eif_ex_63 sloc4;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) sloc4.data;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTCFDT;
	RTLD;
	
	memset (&sloc4.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc4.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc4.overhead, eif_new_type(68, 0x00).id);
	RTLI(12);
	RTLR(0,loc3);
	RTLR(1,arg1);
	RTLR(2,loc6);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc5);
	RTLR(6,loc7);
	RTLR(7,loc2);
	RTLR(8,loc1);
	RTLR(9,loc4);
	RTLR(10,loc8);
	RTLR(11,tr2);
	RTLIU(12);
	
	RTEAA("process_directory", 107, Current, 8, 1, 2853);
	RTGC;
	RTHOOK(1);
	loc3 = RTLNS(eif_new_type(1083, 0x00).id, 1083, _OBJSIZ_3_0_0_1_0_2_0_0_);
	F1084_9228(RTCW(loc3), arg1);
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F1084_9252(RTCW(loc3));
	if (tb2) {
		tr1 = F1084_9242(RTCW(loc3));
		loc6 = tr1;
		tb1 = EIF_TEST(loc6);
	}
	if (tb1) {
		RTHOOK(3);
		{
			static EIF_TYPE_INDEX typarr0[] = {853,1332,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc5 = RTLNS(typres0.id, 853, _OBJSIZ_1_1_0_1_0_0_0_0_);
		}
		ti4_1 = F854_8461(loc6);
		F854_8440(RTCW(loc5), ti4_1);
		RTHOOK(4);
		loc7 = F854_8454(loc6);
		for (;;) {
			tb1 = F997_8915(loc7);
			if (tb1) break;
			RTHOOK(5);
			loc2 = F997_8906(loc7);
			RTHOOK(6);
			if ((EIF_BOOLEAN) !F109_2679(Current, loc2)) {
				RTHOOK(7);
				if ((EIF_BOOLEAN) !F108_2670(Current, loc2)) {
					RTHOOK(8);
					loc1 = F1084_9232(RTCW(loc3));
					loc1 = F1333_12994(RTCW(loc1), loc2);
					RTHOOK(9);
					tb2 = F69_2045(RTCW(loc4), loc1);
					if (tb2) {
						RTHOOK(10);
						F854_8480(RTCW(loc5), loc2);
					}
				}
				RTHOOK(11);
				if ((EIF_BOOLEAN) !F109_2680(Current, loc2)) {
					RTHOOK(12);
					loc1 = F1084_9232(RTCW(loc3));
					loc1 = F1333_12994(RTCW(loc1), loc2);
					RTHOOK(13);
					tb2 = F69_2056(RTCW(loc4), loc1);
					if (tb2) {
						RTHOOK(14);
						F109_2678(Current, loc1);
					}
				}
			}
			RTHOOK(15);
			F997_8921(loc7);
		}
		RTHOOK(16);
		loc8 = F854_8454(RTCW(loc5));
		for (;;) {
			tb2 = F997_8915(loc8);
			if (tb2) break;
			
			RTHOOK(18);
			tr1 = F1084_9232(RTCW(loc3));
			tr2 = F997_8906(loc8);
			tr1 = F1333_12994(RTCW(tr1), tr2);
			F109_2677(Current, tr1);
			RTHOOK(19);
			F997_8921(loc8);
		}
	}
	RTHOOK(20);
	RTLE;
	RTEE;
}

/* {DIRECTORY_ITERATOR}.path_excluded */
EIF_BOOLEAN F108_2669 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("path_excluded", 107, Current, 0, 1, 2855);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	tb1 = F1333_12971(RTCW(arg1));
	if (!tb1) {
		tb1 = F1333_12972(RTCW(arg1));
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {DIRECTORY_ITERATOR}.directory_excluded */
EIF_BOOLEAN F108_2670 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("directory_excluded", 107, Current, 0, 1, 2856);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

void EIF_Minit91 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
